@@ -1,4 +1,5 @@
 import unittest
+import os
 from nfstream import NFStreamer
 import numpy as np
 from EIMTC.plugins.n_pkts_byte_freq import NPacketsByteFrequency
@@ -11,6 +12,8 @@ from EIMTC.plugins.clump_flows import Clump_Flow
 from EIMTC.plugins.packets_size_interarrival_time import Packets_size_and_interarrival_time
 from EIMTC.plugins.n_bytes import NBytes
 
+dirname = os.path.dirname(__file__)
+pcaps_dir = os.path.join(dirname, 'pcaps')
 
 '''
     Testing NFStream Plugins
@@ -23,7 +26,7 @@ class TestNBytes(unittest.TestCase):
     def test_100_bytes_udp_dns_single_packet(self):
         # Given
         plugins = [NBytes(n=100)]
-        pcap_filepath = './pcaps/dns_2_single_response_packet.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'dns_2_single_response_packet.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -46,7 +49,7 @@ class TestNBytes(unittest.TestCase):
     def test_200_bytes_udp_dns_single_packet(self):
         # Given
         plugins = [NBytes(n=200)]
-        pcap_filepath = './pcaps/dns_2_single_response_packet.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'dns_2_single_response_packet.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -76,7 +79,7 @@ class TestNBytes(unittest.TestCase):
     def test_184_bytes_udp_dhcpv6(self):
         # Given
         plugins = [NBytes(n=184)]
-        pcap_filepath = './pcaps/dhcpv6_request_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'dhcpv6_request_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -110,7 +113,7 @@ class TestNBytes(unittest.TestCase):
         '''
         # Given
         plugins = [NBytes(n=100)]
-        pcap_filepath = './pcaps/udp_skype_eth_padding_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'udp_skype_eth_padding_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -139,7 +142,7 @@ class TestNBytes(unittest.TestCase):
         '''
         # Given
         plugins = [NBytes(n=120)]
-        pcap_filepath = './pcaps/udp_skype_eth_padding_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'udp_skype_eth_padding_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -164,7 +167,7 @@ class TestNBytes(unittest.TestCase):
     def test_200_bytes_udp_snmp_ipv6(self):
         # Given
         plugins = [NBytes(n=200)]
-        pcap_filepath = './pcaps/snmp_ipv6_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'snmp_ipv6_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -193,7 +196,7 @@ class TestNBytes(unittest.TestCase):
     def test_100_bytes_tcp_tls_single_packet(self):
         # Given
         plugins = [NBytes(n=100)]
-        pcap_filepath = './pcaps/tls_client_hello_single_packet.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_client_hello_single_packet.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -216,7 +219,7 @@ class TestNBytes(unittest.TestCase):
     def test_16_bytes_tcp_ack_empty_single_packet(self):
         # Given
         plugins = [NBytes(n=16)]
-        pcap_filepath = './pcaps/tcp_ack_single_packet.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tcp_ack_single_packet.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -234,7 +237,7 @@ class TestNBytes(unittest.TestCase):
     def test_16_bytes_tcp_syn_empty_single_packet(self):
         # Given
         plugins = [NBytes(n=16)]
-        pcap_filepath = './pcaps/tcp_syn_single_packet.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tcp_syn_single_packet.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -252,7 +255,7 @@ class TestNBytes(unittest.TestCase):
     def test_300_bytes_tcp_http(self):
         # Given
         plugins = [NBytes(n=300)]
-        pcap_filepath = './pcaps/http_most_freq_payload_ratio_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'http_most_freq_payload_ratio_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamers
@@ -292,7 +295,7 @@ class TestClumpsPlugin(unittest.TestCase):
 
     def test_clump_flow_1(self):
             # Given
-        pcap_filepath = './pcaps/tls_pkt_rel_time_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_pkt_rel_time_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=self.plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -449,7 +452,7 @@ class TestClumpsPlugin(unittest.TestCase):
 
     def test_clump_flow_2(self):
         # Given
-        pcap_filepath = './pcaps/tls_small_pkt_payload_ratio_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_small_pkt_payload_ratio_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=self.plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -614,7 +617,7 @@ class TestPacketsSizeInterarrivalTimePlugin(unittest.TestCase):
     
     def test_packets_size_and_interarrival_time_1(self):
         # Given
-        pcap_filepath = './pcaps/tls_pkt_rel_time_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_pkt_rel_time_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=self.plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -652,7 +655,7 @@ class TestPacketsSizeInterarrivalTimePlugin(unittest.TestCase):
 
     def test_packets_size_and_interarrival_time_2(self):
         # Given
-        pcap_filepath = './pcaps/tls_small_pkt_payload_ratio_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_small_pkt_payload_ratio_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=self.plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -710,7 +713,7 @@ class TestDNSCounter(unittest.TestCase):
         # TODO: read a file with a single flow, as multiprocessing by n_meters can reorder the flows
         # Given
         plugins = [DNSCounter()]
-        pcap_filepath = './pcaps/dns_1.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'dns_1.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins, n_meters=1)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -791,7 +794,7 @@ class TestMostFreqPayloadRatio(unittest.TestCase):
     def test_most_freq_payload_ratio_1(self):
         # Given
         plugins = [MostFreqPayloadLenRatio()]
-        pcap_filepath = './pcaps/http_most_freq_payload_ratio_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'http_most_freq_payload_ratio_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -814,7 +817,7 @@ class TestSmallPacketPayloadRatio(unittest.TestCase):
     def test_small_pkt_payload_ratio_1(self):
         # Given
         plugins = [SmallPacketPayloadRatio()]
-        pcap_filepath = './pcaps/tls_small_pkt_payload_ratio_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_small_pkt_payload_ratio_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -837,7 +840,7 @@ class TestPacketRelativeTime(unittest.TestCase):
     def test_pkt_rel_time_1(self):
         # Given
         plugins = [PacketRelativeTime()]
-        pcap_filepath = './pcaps/tls_pkt_rel_time_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_pkt_rel_time_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -882,7 +885,7 @@ class TestByteFrequencyPlugin(unittest.TestCase):
     def test_byte_frequency_1(self):
         # Given
         plugins = [NPacketsByteFrequency(n_first_packets=1)]
-        pcap_filepath = './pcaps/tls_pkt_rel_time_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_pkt_rel_time_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -958,7 +961,7 @@ class TestByteFrequencyPlugin(unittest.TestCase):
     def test_byte_frequency_2(self):
         # Given
         plugins = [NPacketsByteFrequency(n_first_packets=2)]
-        pcap_filepath = './pcaps/tls_pkt_rel_time_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_pkt_rel_time_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -1040,7 +1043,7 @@ class TestReqResDiffTimePlugin(unittest.TestCase):
 
     def test_stream_req_res_diff_time_1(self):
         # Given
-        pcap_filepath = './pcaps/tls_req_res_diff_time_single.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_req_res_diff_time_single.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=self.plugins)
         # When
         flows = list(streamer) # read streams/flows streamer
@@ -1071,7 +1074,7 @@ class TestReqResDiffTimePlugin(unittest.TestCase):
             
     def test_stream_req_res_diff_time_2(self):
         # Given / Arrange
-        pcap_filepath = './pcaps/tls_req_res_diff_time_single_2.pcap'
+        pcap_filepath = os.path.join(pcaps_dir, 'tls_req_res_diff_time_single_2.pcap')
         streamer = NFStreamer(source=pcap_filepath, udps=self.plugins)
         # When / Act
         flows = list(streamer) # read streams/flows streamer
